#!/usr/bin/env node

import * as fs from 'fs';
import * as path from 'path';

import * as commandLineUsage from 'command-line-usage';

import * as exampleConfig from '../config.example.json';
import { getLogger, setLogLevels } from './loggers';
import QQBot from './koishi';

const logger = getLogger();

const sections: commandLineUsage.Section[] = [
  {
    header: 'GoCQHTTP Nana Bot',
    content: 'The QQ Bot that does stuff.',
  },
  {
    header: 'Synopsis',
    content: [
      '$ cq-nana-bot {underline config.json}',
      '$ cq-nana-bot {bold --help}',
    ],
  },
  {
    header: 'Documentation',
    content: [
      'Project home: {underline https://github.com/CL-Jeremy/mirai-twitter-bot}',
      'Example config: {underline https://git.io/JJ0jN}',
    ],
  },
];

const usage = commandLineUsage(sections);

const args = process.argv.slice(2);

if (args.length === 0 || args[0] === 'help' || args[0] === '-h' || args[0] === '--help') {
  console.log(usage);
  process.exit(0);
}

const configPath = args[0];

type Config = typeof exampleConfig;
let config: Config;
try {
  config = JSON.parse(fs.readFileSync(path.resolve(configPath), 'utf8')) as Config;
} catch (e) {
  console.log('Failed to parse config file: ', configPath);
  console.log(usage);
  process.exit(1);
}

const requiredFields = [
  'cq_bot_qq',
];

const warningFields = [
  'cq_ws_host', 'cq_ws_port', 'cq_access_token',
];

if (requiredFields.some((value) => config[value] === undefined)) {
  console.log(`${requiredFields.join(', ')} are required`);
  process.exit(1);
}

warningFields.forEach(key => {
  if (config[key] === undefined || typeof(config[key]) !== typeof (exampleConfig[key])) {
    logger.warn(`${key} is undefined, use ${exampleConfig[key] || 'empty string'} as default`);
    config[key] = exampleConfig[key as keyof Config];
  }
});

setLogLevels(config.loglevel);

const qq = new QQBot({
  access_token: config.cq_access_token,
  host: config.cq_ws_host,
  port: config.cq_ws_port,
  bot_id: config.cq_bot_qq,
});

qq.connect();
